@@ -1,11 +1,9 @@
-# coding: utf8
+__version__ = '2.0'
 
-__version__ = '1.1'
-
-from structure import *
-from types import *
-from types_datetime import *
-from dict import from_dict, to_dict
+from .structure import *
+from .types import *
+from .types_datetime import *
+from .dict import from_dict, to_dict
 
 __all__ = [
            'Structure',
